# Sitemap status

Logs the http status for each sitemap location in the status report
and adds an entry to the Admin Toolbar.

Use case: while doing a deployment (production or pull request based environment),
be able to check the status of each page from the sitemap based on a production database.
As unit/E2E tests might contain testing gaps and/or possibly not catch "content based"
issues (like redirects/aliases), this can be used as an affordable smoke test.

## Dependencies

[Simple XML Sitemap](https://www.drupal.org/project/simple_sitemap)

## Configuration

Can be used without any configuration via drush.

Optional configuration for UI or cron based checks:
Configuration > Development > Sitemap status
(/admin/config/development/sitemap-status).

Drush can be used on build e.g. within a post-rollout task.
Example: generate the sitemap then run the check.

```
- run:
    name: drush ssg
    command: drush simple-sitemap:generate
    service: cli
- run:
    name: drush ssc
    command: drush sitemap-status:check
    service: cli
```

## Usage

`drush sitemap-status:check` (alias: drush ssc)

Options examples:
- adds basic auth for PR / staging environments
- adds a path prefix (e.g. to isolate other 301 redirects)
- use async check with concurrent requests set to 15 (defaults to 10)
- skip the check on excluded urls (e.g. not in the production build)
- print http headers

```
drush ssc \
--basic-auth=username:password \
--path-prefix=europe \
--async=true \
--concurrent-requests=10
--excluded-urls=https://nginx-production.mysite.org,https://mysite.org \
--print-headers=true
```

## Credits

Thank you [@dan2k3k4](https://www.drupal.org/u/dan2k3k4) for the original idea :)

## Roadmap

- Improve the integration with the Toolbar, make it optional
- Optional follow redirect
- Expose the sitemap status as json for external polling
- Only http status is checked, add error or element (e.g. title) check
- Improve drush command parameters validation
- Improve caching invalidation of the Toolbar
- ~~Reduce check time, optionally use curl_multi~~
- ~~Trigger the status check from the ui~~
- ~~Optional cron based check~~
- ~~Make use of a specific cache backend~~
