<?php

namespace Drupal\sitemap_status;

/**
 * Interface SitemapStatusInterface.
 */
interface SitemapStatusInterface {

  const CACHE_ID = 'sitemap_status';

  const REQUIREMENT_UNKNOWN = -2;
  const REQUIREMENT_INFO = -1;
  const REQUIREMENT_OK = 0;
  const REQUIREMENT_WARNING = 1;
  const REQUIREMENT_ERROR = 2;

  const STATUS_NOT_REACHED = '0';
  const STATUS_2xx = '2';
  const STATUS_3xx = '3';
  const STATUS_4xx = '4';
  const STATUS_5xx = '5';

  const MAX_CONCURRENT_REQUESTS = 10;

  const LOCATIONS_GROUP = 'locations_group';
  const LOCATION = 'location';

  /**
   * Checks the sitemap locations.
   *
   * Returns an array of locations indexed by http statuses.
   * As a side effect, caches the result.
   *
   * Uses a queue, meant to be used by drush and cron only.
   *
   * @param string $basic_auth
   * @param string $path_prefix
   * @param bool $async
   * @param bool $print_headers
   *
   * @return array|int[]
   */
  public function checkLocations($basic_auth = '', $path_prefix = '', $async = FALSE, $print_headers = FALSE);

  /**
   * @param string $basic_auth
   */
  public function setBasicAuth($basic_auth);

  /**
   * Returns an array of locations from a sitemap.
   *
   * @return string[]|array
   */
  public function fetchSitemapLocations();

  /**
   * Groups locations by http status.
   *
   * @param string[] $locations
   *
   * @return int[]
   */
  public function groupLocationsByStatus(array $locations);

  /**
   * Returns an array of locations indexed by http statuses.
   *
   * @return array|int[]
   */
  public function getLocationsStatuses();

  /**
   * Returns an array of locations indexed by http statuses groups.
   *
   * @return array|string[]
   */
  public function getLocationsStatusesByGroup();

  /**
   * Returns the status level, to be used in system.status.
   *
   * @return int
   */
  public function getStatusLevel();

  /**
   * Returns the status level icon.
   *
   * @return string
   */
  public function getStatusLevelIcon();

  /**
   * Returns the status summary.
   *
   * @return array
   *   Render array.
   */
  public function getStatusSummary();

  /**
   * Checks if an url is valid.
   *
   * @param string $url
   *
   * @return bool
   */
  public function isUrlValid($url);

  /**
   * Returns the http status for a location.
   *
   * @param string $location
   *
   * @return int
   */
  public function fetchLocationStatus($location);

  /**
   * Returns the http status for several locations.
   *
   * @param array $locations
   *
   * @return array|string[]
   *   Locations as key with status as value.
   */
  public function fetchLocationStatusMultiple(array $locations);

}
